#ifndef POKEPLATINUM_UNK_0200AC5C_H
#define POKEPLATINUM_UNK_0200AC5C_H

#include "struct_decls/struct_02006C24_decl.h"
#include "struct_decls/struct_0200AC5C_decl.h"
#include "struct_decls/struct_0200B144_decl.h"
#include "strbuf.h"

UnkStruct_0200AC5C * sub_0200AC5C(u32 param0, u32 param1, u32 param2);
void sub_0200AC64(UnkStruct_0200AC5C * param0);
void sub_0200AC6C(const UnkStruct_0200AC5C * param0, u32 param1, u16 * param2);
void sub_0200ACF0(u32 param0, u32 param1, u32 param2, u32 param3, u16 * param4);
void sub_0200ADAC(const UnkStruct_0200AC5C * param0, u32 param1, Strbuf *param2);
Strbuf* sub_0200AE5C(const UnkStruct_0200AC5C * param0, u32 param1, u32 param2);
void sub_0200AF20(u32 param0, u32 param1, u32 param2, u32 param3, Strbuf *param4);
void sub_0200AF48(NARC * param0, u32 param1, u32 param2, u32 param3, Strbuf *param4);
Strbuf* sub_0200B010(u32 param0, u32 param1, u32 param2, u32 param3);
Strbuf* sub_0200B044(NARC * param0, u32 param1, u32 param2, u32 param3);
u32 sub_0200B120(const UnkStruct_0200AC5C * param0);
u32 sub_0200B124(u32 param0, u32 param1);
UnkStruct_0200B144 * sub_0200B144(int param0, u32 param1, u32 param2, u32 param3);
void sub_0200B190(UnkStruct_0200B144 * param0);
void sub_0200B1B8(const UnkStruct_0200B144 * param0, u32 param1, Strbuf *param2);
Strbuf* sub_0200B1EC(const UnkStruct_0200B144 * param0, u32 param1);
u32 sub_0200B218(const UnkStruct_0200B144 * param0);
void sub_0200B240(const UnkStruct_0200B144 * param0, u32 param1, u16 * param2);
void sub_0200B274(u32 param0, u32 param1, u16 * param2);

#endif // POKEPLATINUM_UNK_0200AC5C_H
